/*
 * schq_launcher_template.h
 * Define class Launcher_template.
 *
 * Copyright (c) 2010 Vasily Eremenko <vasily.eremenko@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// **********************************************
# include <iostream>
# include <string>
# include <stdexcept>
# include <typeinfo>
# include <cstdlib>
# include <cstdio>

# include <libconfig.h++>

# include <log4cpp/Category.hh>
# include <log4cpp/Configurator.hh>
# include <log4cpp/PropertyConfigurator.hh>

# include "schq_receptionist.h"

// **********************************************
namespace schq
{
  template<class T> class Launcher_template
  {
  public:
    /*
     * Constructor(s).
     */
    Launcher_template()
    {
      // Nothing to do.
    } // Launcher_template()

    // ****************************************************
    static void write_line_error_message(const std::string & src_filename,
					 const int src_lineno,
					 const std::string & message)
    {
      std::cerr << program_name << ": " << src_filename
		<< "(" << src_lineno << "): "
		<< message << std::endl;
    } // write_line_error_message()

    // ****************************************************
    static void Main(const int argc, const char * argv[])
    {
      try
	{
	  Receptionist fred(argc, argv);
	  libconfig::Setting & root = fred.get_config().getRoot();
	  try
	    {
	      log4cpp::PropertyConfigurator::configure(root["log_config"]);
	    }
	  catch(log4cpp::ConfigureFailure & e)
	    {
	      std::string msg = "log4cpp::ConfigureFailure catched. ";
	      msg += "Message:";
	      write_line_error_message(__FILE__, __LINE__, msg);
	      write_line_error_message(__FILE__, __LINE__, e.what());
	      std::exit(1);
	    }
	  std::string log_category = "main";
	  std::string fatal_log_category = "main.fatal";
	  log4cpp::Category & log =
	    log4cpp::Category::getInstance(log_category);
	  log4cpp::Category & fatal_log =
	    log4cpp::Category::getInstance(fatal_log_category);
	  try
	    {
	      log.notice("application: start.");

	      T runner(root, log);
	      runner.run();

	      log.debug("Prepare output.");
	      libconfig::Config output;
	      libconfig::Setting & oroot = output.getRoot();
	      runner.to_setting_as_children(oroot);

	      log.debug("Write output.");
	      std::cout.sync_with_stdio();
	      output.write(stdout);

	      log.notice("application: finish.");
	    }
	  catch(std::exception & e)
	    {
	      std::string msg = "An exception catched! Type: ";
	      msg += typeid(e).name();
	      msg += ". Message: ";
	      msg += e.what();
	      fatal_log.fatal(msg);
	      std::exit(1);
	    }
	}
      catch(std::exception & e)
	{
	  std::string msg = "An exception catched! Type: ";
	  msg += typeid(e).name();
	  msg += ". Message: ";
	  msg += e.what();
	  write_line_error_message(__FILE__, __LINE__, msg);
	  std::exit(1);
	}
    } // Main()
  }; // Launcher_template
} // schq
