/*
 * particle.h
 * Define class Particle.
 *
 * Copyright (c) 2010 Vasily Eremenko <vasily.eremenko@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// **********************************************
#ifndef SCHQ_PARTICLE_H
#define SCHQ_PARTICLE_H

// **********************************************
# include <string>
# include <stdexcept>
# include <sstream>

# include <libconfig.h++>

// **********************************************
namespace schq
{

  // **********************************************
  class Particle
  {
  private:
    double mass_val;
    int electric_charge;

  public:
    /*
     * Constructor.
     */
    Particle()
      {
	// Nothing to do!
      } // Particle()

    /*
     * Destructor.
     */
    virtual ~Particle()
      {
	// Nothing to do!
      } // ~Particle()

    // **********************************************
    /*
     * void set_parameters(const libconfig::Setting & part)
     * Set parameters.
     */
    void set_parameters(const libconfig::Setting & part)
      {
	mass_val = part["mass"];
	electric_charge = part["Z"];
      } // set_parameters()

    // **********************************************
    /*
     * double mass() const
     * Returns mass value.
     */
    double mass() const
    {
      return mass_val;
    }

    // **********************************************
    /*
     * int Z() const
     * Returns electric charge value.
     */
    int Z() const
    {
      return electric_charge;
    }
  }; // class Particle

  // **********************************************
} // namespace schq

// **********************************************
#endif // SCHQ_PARTICLE_H

// **********************************************
// End of file.
// **********************************************
