/*
 * physical_constants.h
 * Define class Physical_constants.
 *
 * Copyright (c) 2010 Vasily Eremenko <vasily.eremenko@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// **********************************************
#ifndef SCHQ_PHYSICAL_CONSTANTS_H
#define SCHQ_PHYSICAL_CONSTANTS_H

// **********************************************
# include <iostream>
# include <string>
# include <stdexcept>

# include <libconfig.h++>

# include <log4cpp/Category.hh>

# include "schq_bookworm.h"

// **********************************************
namespace schq
{
  class Physical_constants : public Bookworm
  {
  private:
    double alpha_val;
    double hc_val;

    // **********************************************
  public:
    /*
     * Constructor(s).
     */
    Physical_constants(const libconfig::Setting & constants,
		       log4cpp::Category & uplevel_log) :
    Bookworm(uplevel_log, "constants")
      {
	get_log().debug("Physical_constants(): start.");

	hc_val = constants["hc"];
	alpha_val = constants["alpha"];

	log4cpp::CategoryStream ost(get_log().infoStream());
	ost << "hc = " << hc();
	log4cpp::eol(ost);
	ost << "alpha = " << alpha();
	log4cpp::eol(ost);

	get_log().debug("Physical_constants(): finish.");
      } // Physical_constants()

    // **********************************************
    /*
     * Destructor.
     */
    virtual ~Physical_constants()
      {
	// Nothing to do!
      } // ~Physical_constants()

    // **********************************************
    /*
     * double alpha() const
     * Returns value of alpha (fine structure const).
     */
    double alpha() const
    {
      return alpha_val;
    }

    // **********************************************
    /*
     * double hc() const
     * Returns value of hc (fm^-1 to MeV casting const).
     */
    double hc() const
    {
      return hc_val;
    }
  }; // class Physical_constants

  // **********************************************
} // namespace schq

// **********************************************
#endif // SCHQ_PHYSICAL_CONSTANTS_H

// **********************************************
// End of file.
// **********************************************
