/*
 * potentials_base.h
 * Define class Potentials_base
 *
 * Copyright (c) 2010 Vasily Eremenko <vasily.eremenko@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// **********************************************
#ifndef SCHQ_POTENTIALS_BASE_H
#define SCHQ_POTENTIALS_BASE_H

// **********************************************
# include <libconfig.h++>

# include <log4cpp/Category.hh>

# include "schq_bookworm.h"
# include "schq_physical_system_base.h"

// **********************************************
namespace schq
{
  class Potentials_base : public Bookworm
  {
  public:
    /*
     * Constructor.
     */
    Potentials_base(const libconfig::Setting & potentials,
		    const log4cpp::Category & uplevel_log) :
    Bookworm(uplevel_log, "potentials")
      {
	get_log().debug("Potentials_base(): start.");
	get_log().debug("Potentials_base(): finish.");
      } // Potentials_base()

    // **********************************************
    /*
     * Destructor.
     */
    virtual ~Potentials_base()
      {
	// Nothing to do.
      }

    // **********************************************
    /*
     * double dVN(const double r, const Physical_system_base & sys) const
     * Returns value of derivative of nuclear interaction
     * potential at point r.
     * Here it is pure virtual method!
     * Derivative classes MUST redefine it!
     */
    virtual double dVN(const double r,
		       const Physical_system_base & sys) const = 0;

    // **********************************************
    /*
     * double dVC(const double r, const Physical_system_base & sys) const
     * Returns value ofderivative of Coulomb interaction
     * potential at point r.
     * Here it is pure virtual method!
     * Derivative classes MUST redefine it!
     */
    virtual double dVC(const double r,
		       const Physical_system_base & sys) const = 0;

    // **********************************************
    /*
     * double k0_momentum(const Physical_system_base & sys) const
     * Returns value of k0.
     * Here it is pure virtual method!
     * Derivative classes MUST redefine it!
     */
    virtual double k0_momentum(const Physical_system_base & sys) const = 0;

    // **********************************************
    /*
     * double VN(const double r, const Physical_system_base & sys) const
     * Returns value of nuclear interaction potential at point r.
     * Here it is pure virtual method!
     * Derivative classes MUST redefine it!
     */
    virtual double VN(const double r,
		      const Physical_system_base & sys) const = 0;

    // **********************************************
    /*
     * double VC(const double r, const Physical_system_base & sys) const
     * Returns value of Coulomb interaction potential at point r.
     * Here it is pure virtual method!
     * Derivative classes MUST redefine it!
     */
    virtual double VC(const double r,
		      const Physical_system_base & sys) const = 0;
  }; // class Potentials_base

  // **********************************************
} // namespace schq

// **********************************************
#endif // SCHQ_POTENTIALS_BASE_H

// **********************************************
// End of file.
// **********************************************
