/*
 * solver_rkf45.h
 * Define class Solver_rkf45.
 *
 * Copyright (c) 2010 Vasily Eremenko <vasily.eremenko@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// **********************************************
#ifndef SCHQ_SOLVER_RKF45_H
#define SCHQ_SOLVER_RKF45_H

// **********************************************
# include <gsl/gsl_odeiv.h>

# include <libconfig.h++>

# include <log4cpp/Category.hh>

# include "schq_solver_base.h"

// **********************************************
namespace schq
{
  // **********************************************
  class Solver_rkf45 : public Solver_base
  {
  public:
    /*
     * Constructor.
     */
  Solver_rkf45(Physical_system_base * sys,
	       const libconfig::Setting & numeric,
	       log4cpp::Category & uplevel_log) :
    Solver_base(sys, numeric, uplevel_log)
    {
      get_log().debug("Solver_rkf45(): start.");
      // Nothing to do!
      get_log().debug("Solver_rkf45(): finish.");
    } // Solver_rkf45()

    // ****************************************************
    /*
     * Destructor.
     */
    virtual ~Solver_rkf45()
      {
	// Nothing to do!
      } // ~Solver_rkf45()


    // ****************************************************
    /*
     * const gsl_odeiv_step_type * algorythm() const
     * Fixes the algorythm to solve Schroedinger equation.
     */
    virtual const gsl_odeiv_step_type * algorythm() const
    {
      const gsl_odeiv_step_type * retval = gsl_odeiv_step_rkf45;
      return retval;
    } // algorythm()
  }; // Solver_rkf45

  // **********************************************
} // namespace schq

// **********************************************
#endif // SCHQ_SOLVER_RKF45_H

// **********************************************
// End of file.
// **********************************************
